@@ -13,20 +13,6 @@ test_that("get_connection notifies if connection fails", {
   }
 })
 
-test_that("get_connection warns about unsupported backend", {
-  tryCatch(get_connection(drv = character(0)),
-           error = function(e) {
-             expect_error(e, regexp = paste("unable to find an inherited method for function",
-                                            "'dbCanConnect' for signature '\"character\"'"))
-           },
-           warning = function(w) {
-             # Somehow expect_warning does not match the correctly with regex. Even though expect_error does above...
-             checkmate::expect_character(w$message,
-                                         pattern = "Driver of class 'character' is currently not fully supported")
-           })
-})
-
-
 test_that("id() works", { for (conn in conns) { # nolint: brace_linter
 
   expect_identical(id("test_mtcars"), DBI::Id(table = "test_mtcars"))
@@ -55,9 +41,21 @@ test_that('id() returns table = "schema.table" if schema does not exist', {
   }
 })
 
+test_that("id() is consistent for DBI connections", {
+  expectation <- id(dplyr::tbl(conn, DBI::Id(schema = "test", table = "mtcars")))
+  for (conn in conns) {
+    expect_identical(expectation,
+                     id.tbl_dbi(dplyr::tbl(
+                       conn, DBI::Id(schema = "test", table = "mtcars")
+                     )))
+  }
+})
 
 test_that("close_connection() works", { for (conn in conns) { # nolint: brace_linter
 
+  # ODBC connections require arguments and therefore cannot be used in this test
+  if (inherits(conn, "OdbcConnection")) next
+
   # Identify driver of conn within conn_list
   conn_drv <- purrr::keep(conns, \(.x) identical(.x, conn)) |>
     names() |>
